use strict;
use warnings;
use Data::Dumper; $Data::Dumper::Indent = 1;
use Test::More 'no_plan';

use Atompub::Client;
use URI::Escape;
use XML::Atom::Entry;

ok my $client = Atompub::Client->new;

my $entry_collection = 'http://localhost:3000/entrycollection';

my $entry = XML::Atom::Entry->new;
   $entry->updated('2008-01-01T:00:00:00Z');
   $entry->title('東京都');
   $entry->content('東京オリンピックについて');
my $author = XML::Atom::Person->new;
   $author->name('石原');
   $entry->author($author);
my $category = XML::Atom::Category->new;
   $category->term('オリンピック');
   $entry->category($category);

ok $client->createEntry($entry_collection, $entry);

$entry->updated('2008-01-02T:00:00:00Z');
$entry->title('京都府');
$entry->content('京都議定書について');
$author = XML::Atom::Person->new;
$author->name('山田');
$entry->author($author);
$category = XML::Atom::Category->new;
$category->term('エコ');
$entry->category($category);

ok $client->createEntry($entry_collection, $entry);

ok my $feed = $client->getFeed("$entry_collection?q=".uri_escape('京都'));
is $feed->entries, 2;

ok $feed = $client->getFeed("$entry_collection?q=".uri_escape('京都 石原'));
is $feed->entries, 1;
($entry) = $feed->entries;
is $entry->title, '東京都';

ok $feed = $client->getFeed("$entry_collection?q=".uri_escape('京都 OR 石原'));
is $feed->entries, 2;

ok $feed = $client->getFeed("$entry_collection?q=".uri_escape('京都 -石原'));
is $feed->entries, 1;
($entry) = $feed->entries;
is $entry->title, '京都府';

ok $feed = $client->getFeed("$entry_collection?author=".uri_escape('石原'));
is $feed->entries, 1;
($entry) = $feed->entries;
is $entry->title, '東京都';

ok $feed = $client->getFeed("$entry_collection/-/".uri_escape('エコ'));
is $feed->entries, 1;
($entry) = $feed->entries;
is $entry->title, '京都府';

ok $feed = $client->getFeed("$entry_collection?updated-min=2008-01-02T00:00:00Z");
is $feed->entries, 1;
($entry) = $feed->entries;
is $entry->title, '京都府';

ok $feed = $client->getFeed("$entry_collection?q=".uri_escape('京都').'&updated-max=2008-01-02T00:00:00Z');
is $feed->entries, 1;
($entry) = $feed->entries;
is $entry->title, '東京都';
